<line x1="76.901" y1="34.748" x2="23.127" y2="65.767" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<line x1="23.127" y1="34.748" x2="76.762" y2="65.767" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<line x1="50" y1="19.099" x2="50.014" y2="81.177" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<polyline points="69.817 23.708 65.184 41.507 82.802 46.024" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<polyline points="37.045 20.133 50.608 32.555 62.844 19.099" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<polyline points="62.908 79.936 50.08 66.756 37.092 79.488" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<polyline points="30.127 23.708 34.759 41.507 17.142 46.024" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<polyline points="30.127 76.176 34.759 58.377 17.142 53.86" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<polyline points="69.817 76.176 65.184 58.377 82.802 53.86" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>