<circle cx="38.471" cy="65.321" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="49.648" cy="65.321" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="60.826" cy="65.321" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="44.763" cy="76.374" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="55.941" cy="76.374" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="32.882" cy="54.143" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="44.059" cy="54.143" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="55.941" cy="54.143" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="67.118" cy="54.143" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="32.882" cy="42.673" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="44.059" cy="42.673" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="55.941" cy="42.673" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="67.118" cy="42.673" r="5.589" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<path d="M36.408,29.108s3.869,7.264,8.355,7.264,6.173-4.799,5.589-11.025,6.29-8.95,6.29-8.95" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<path d="M50.352,25.347s.583,19.067,13.554,4.799" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
