<path d="M39.291,49.274c-7.951,0-14.387-6.448-14.387-14.387s6.437-14.399,14.387-14.399" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="74.539 20.488 39.293 20.488 39.293 79.512" fill="none" class="svg-stroke-primary" stroke-linecap="round"
          stroke-linejoin="round" stroke-width="6"/>
<line x1="59.193" y1="79.512" x2="59.193" y2="20.488" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
