<circle cx="50" cy="50" r="28.446" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="8"/>
<path d="M50,50c0-15.71,12.736-28.446,28.446-28.446" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M21.554,21.554c15.71,0,28.446,12.736,28.446,28.446" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<circle cx="35.777" cy="45.954" r="6" fill="none" class="svg-fill-primary"/>
<circle cx="64.223" cy="45.954" r="6" fill="none" class="svg-fill-primary"/>
