{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <circle cx="50" cy="49.996" r="32" fill="#fff" stroke="#f2f2f2" stroke-miterlimit="10" stroke-width=".25"/>
    <circle cx="50" cy="50" r="19.203" fill="#c00026"/>
{% endblock %}
