<circle cx="50" cy="66.194" r="12.872" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round" stroke-width="8"/>
<ellipse cx="50" cy="48.014" rx="8.759" ry="3.747" fill="none" class="svg-stroke-primary" stroke-linecap="round"
         stroke-linejoin="round" stroke-width="8"/>
<path d="M44.345,42.707s-7.533-9.503-3.104-21.773c0,0,7.541,3.438,5.504,20.667l-2.399,1.107Z" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M57.277,42.707s7.533-9.503,3.104-21.773c0,0-7.541,3.438-5.504,20.667l2.399,1.107Z" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>