<path d="M69,49.596s4.71,28.16-16.91,30.26" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M47.57,79.896c-20.41-1.68-15.99-30.3-15.99-30.3" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M76.45,49.593H23.55s4.556-15.938,26.897-15.938,26.004,15.938,26.004,15.938Z" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M50.446,33.654s-3.673-9.818,1.641-13.628" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M47.567,79.89s2.433,6.695,4.519-.043" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
