<path d="M25.954,67.448V32.057H60.526l10.978,10.486h11.469l-4.096,4.096v13.436s-6.718,.164-7.373-7.373h-7.865l-6.882,6.882-3.764-6.882h-20.65l-6.158,6.705"
      fill="none" fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
      stroke-width="7"/>
<line x1="37.836" y1="67.943" x2="32.344" y2="52.702" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="7"/>
<line x1="50.582" y1="67.943" x2="52.994" y2="52.702" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="7"/>
<line x1="60.675" y1="67.943" x2="56.758" y2="59.584" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="7"/>
<path d="M17.031,50.237s.115-10.612,0-12.804,1.9-5.377,6.343-5.377" fill="none" fill-rule="evenodd"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="7"/>