<circle cx="50.158" cy="49.587" r="13.348" fill="none" class="svg-stroke-primary" stroke-linecap="round"
        stroke-linejoin="round" stroke-width="8"/>
<path d="M38.917,42.133s-16.63-12.691-11.522-18.288,17.31,8.697,17.741,13.109" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M36.689,49.915s-20.89-1.106-19.827-8.608c1.063-7.502,19.2-2.576,22.043,.824" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M39.113,57.869s-18.209,10.298-21.346,3.4,14.805-12.494,19.03-11.155" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M45.391,62.978s-9.233,18.771-15.713,14.843,5.183-18.666,9.428-19.942" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M53.381,63.431s3.68,20.593-3.867,21.266c-7.547,.673-6.881-18.109-4.217-21.652" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M60.282,59.201s14.65,14.933,8.797,19.744c-5.854,4.811-15.893-11.077-15.69-15.505" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M63.538,51.222s20.788,2.342,19.282,9.768c-1.506,7.426-19.319,1.434-21.955-2.129" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M61.465,42.556s18.209-10.298,21.346-3.4c3.137,6.897-14.805,12.494-19.03,11.155" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M54.69,36.702s9.233-18.771,15.713-14.843c6.479,3.928-5.183,18.666-9.428,19.942" fill="none"
      fill-rule="evenodd" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>
<path d="M45.78,36.777s-4.807-20.359,2.691-21.447,7.866,17.703,5.402,21.387" fill="none" fill-rule="evenodd"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="8"/>