<rect x="17.999" y="17.999" width="64.375" height="62.796" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<line x1="17.999" y1="32.361" x2="82.374" y2="32.361" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<path d="M63.125,66.704s-5.593-5.601,.275-11.57c5.167-5.255-.538-10.193-.538-10.193" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<path d="M51.028,66.704s-5.593-5.601,.275-11.57c5.167-5.255-.538-10.193-.538-10.193" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<path d="M38.931,66.704s-5.593-5.601,.275-11.57c5.167-5.255-.538-10.193-.538-10.193" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
