<rect x="27.676" y="42.336" width="44.648" height="31.99" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<line x1="19.192" y1="82.001" x2="83.567" y2="82.001" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="5"/>
<path d="M58.875,31.308s-3.183-3.188,.157-6.585c2.941-2.991-.306-5.801-.306-5.801" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<path d="M49.99,31.308s-3.183-3.188,.157-6.585c2.941-2.991-.306-5.801-.306-5.801" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<path d="M41.105,31.308s-3.183-3.188,.157-6.585c2.941-2.991-.306-5.801-.306-5.801" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<line x1="21.946" y1="51.933" x2="27.676" y2="51.933" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<line x1="73.691" y1="51.933" x2="79.421" y2="51.933" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
