{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="66.006" width="64" height="16" fill="#ca0c1a"/>
    <rect x="18" y="49.996" width="64" height="16.01" fill="#002a84"/>
    <rect x="18" y="17.996" width="64" height="32" fill="#feca0c"/>
{% endblock %}
