<polygon points="50 68.316 18 68.316 34.4 41.556 39.25 49.876 50 68.316" fill="none" class="svg-stroke-primary"
         stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polygon points="82 68.316 50 68.316 56.05 58.446 61.15 50.126 66.4 41.556 82 68.316" fill="none"
         class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polygon points="61.15 50.126 56.05 58.446 50 68.316 39.25 49.876 50.4 31.686 61.15 50.126" fill="none"
         class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
