<line x1="48.449" y1="46.055" x2="25.019" y2="80.711" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6.569"/>
<line x1="42.145" y1="38.632" x2="57.459" y2="48.985" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6.569"/>
<line x1="42.877" y1="29.732" x2="65.445" y2="44.989" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6.569"/>
<line x1="47.236" y1="23.284" x2="69.804" y2="38.542" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6.569"/>
<line x1="55.223" y1="19.289" x2="70.536" y2="29.642" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6.569"/>
<path d="M71.997,51.1s-4.124,5.113-4.058,7.901c.066,2.789,2.04,4.382,4.058,4.382s3.991-1.594,4.058-4.382c.066-2.789-4.058-7.901-4.058-7.901Z"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="6.569"/>
