{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="18" width="27.4" height="27.45" rx="9.1" class="svg-fill-primary"/>
    <rect x="18" y="54.6" width="27.4" height="27.45" rx="9.1" class="svg-fill-primary"/>
    <rect x="54.6" y="18" width="27.4" height="27.45" rx="9.1" class="svg-fill-primary"/>
    <rect x="54.6" y="54.6" width="27.4" height="27.45" rx="9.1" class="svg-fill-primary"/>
{% endblock %}
