{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="60.696" width="64" height="21.31" fill="#fc0"/>
    <rect x="18" y="39.306" width="64" height="21.39" fill="red"/>
    <rect x="18" y="17.996" width="64" height="21.31"/>
{% endblock %}
