{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="17.996" width="64" height="64.01" fill="#fff"/>
    <circle cx="50" cy="50" r="19.203" fill="#c00026"/>
{% endblock %}
