<line x1="50" y1="16.233" x2="50" y2="83.767" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="6"/>
<polyline points="57.461 20.997 50 28.458 42.539 20.997" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="57.461 79.003 50 71.542 42.539 79.003" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<line x1="20.757" y1="33.117" x2="79.243" y2="66.884" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="28.613 29.037 31.344 39.229 21.152 41.961" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="78.848 58.041 68.656 60.771 71.387 70.964" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<line x1="20.757" y1="66.884" x2="79.243" y2="33.117" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="21.152 58.041 31.344 60.771 28.613 70.964" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<polyline points="71.387 29.037 68.656 39.229 78.848 41.96" fill="none" class="svg-stroke-primary"
          stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>