<line x1="31.469" y1="21.691" x2="65.753" y2="21.691" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="8"/>
<path d="M31.875,44.726s2.301-22.948,16.523-22.948c14.374,0,17.355,28.222,17.355,28.222" fill="none" class="svg-stroke-primary"
      stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
<circle cx="30.478" cy="57.205" r="12.479" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="65.753" cy="66.577" r="16.577" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
