{% extends 'snowebsvg/common/svg.html' %}

{% block svg_content %}
    <rect x="18" y="49.996" width="64" height="32.01" fill="#fcd000"/>
    <rect x="18" y="17.996" width="64" height="32" fill="#004aac"/>
{% endblock %}
