<circle cx="35.102" cy="48.799" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="50" cy="48.799" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="64.898" cy="48.799" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="42.551" cy="61.615" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="50" cy="74.431" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<circle cx="57.449" cy="61.615" r="7.449" fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round"
        stroke-width="6"/>
<path d="M50,41.35s8.962-16.509,13.597-16.396c2.489,.061-8.592,10.967-16.167,7.575-14.167-6.343-8.875-13.871-5.427-14.358,7.997-1.131,13.356,17.298-14.351,12.662"
      fill="none" class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="6"/>
