{% extends 'snowebsvg/common/svg.html' %}

{% load svg_utils %}

{% block svg_content %}
    {% include 'snowebsvg/common/builders/_rect.html' %}
    <g transform="{% scale 0.6 %}">
        {% block builder_base %}{% endblock %}
    </g>
{% endblock %}
