<rect x="30.02" y="32.882" width="29.936" height="48.11" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="5.173"/>
<rect x="59.956" y="32.882" width="10.025" height="48.11" transform="translate(129.936 113.873) rotate(180)" fill="none"
      class="svg-stroke-primary" stroke-linecap="round" stroke-linejoin="round" stroke-width="5.173"/>
<polygon points="69.98 32.882 64.756 22.665 59.956 32.882 69.98 32.882" fill="none" class="svg-stroke-primary"
         stroke-linecap="round" stroke-linejoin="round" stroke-width="5.173"/>
<polygon points="30.049 32.882 34.849 22.665 64.756 22.665 59.956 32.882 30.049 32.882" fill="none" class="svg-stroke-primary"
         stroke-linecap="round" stroke-linejoin="round" stroke-width="5.173"/>
<rect x="34.959" y="19.008" width="29.808" height="3.648" fill="none" class="svg-stroke-primary" stroke-linecap="round"
      stroke-linejoin="round" stroke-width="5.173"/>
